<?php
namespace TrendyBabySpace\FiboAjaxSearch\CmsmastersFramework\Kits\Settings\FiboAjaxSearch;

use TrendyBabySpace\Kits\Settings\Base\Settings_Tab_Base;

use Elementor\Controls_Manager;
use TrendyBabySpace\Core\Utils\Utils;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Gutenberg settings.
 */
class autocomplete extends Settings_Tab_Base {

	public function __construct( $data = array(), $args = null ) {
        parent::__construct( $data, $args );

		$settings = get_option( 'dgwt_wcas_settings' );

		if ( isset( $settings ) || !empty( $settings ) ) {
			add_action( 'admin_init', array( $this, 'update_options' ), 11, 2 );
		}
	}

	/**
	 * Get toggle name.
	 *
	 * Retrieve the toggle name.
	 *
	 * @return string Toggle name.
	 */
	public static function get_toggle_name() {
		return 'autocomplete';
	}

	/**
	 * Get title.
	 *
	 * Retrieve the toggle title.
	 */
	public function get_title() {
		return esc_html__( 'Autocomplete', 'trendy-baby' );
	}

	/**
	 * Get control ID prefix.
	 *
	 * Retrieve the control ID prefix.
	 *
	 * @return string Control ID prefix.
	 */
	protected static function get_control_id_prefix() {
		$toggle_name = self::get_toggle_name();

		return parent::get_control_id_prefix() . "_{$toggle_name}";
	}

	/**
	* Register toggle controls.
	*
	* Registers the controls of the kit settings tab toggle.
	*/
	protected function register_toggle_controls() {
		$this->add_control(
			'search_no_results_text',
			array(
				'label' => __( 'No results label', 'trendy-baby' ),
				'type' => Controls_Manager::TEXT,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'search_no_results_text' ),
					__( 'No results', 'trendy-baby' ),
				),
			)
		);

        $this->add_control(
			'search_see_all_results_text',
			array(
				'label' => __( 'More results label', 'trendy-baby' ),
				'type' => Controls_Manager::TEXT,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'search_see_all_results_text' ),
					__( 'See all products...', 'trendy-baby' ),
				),
			)
		);

        $this->add_control(
			'suggestions_limit',
			array(
				'label' => __( 'Limit', 'trendy-baby' ),
				'type' => Controls_Manager::NUMBER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'suggestions_limit' ),
					'7',
				),
				'description' => __( 'maximum number of suggestions', 'trendy-baby' ),
			)
		);

        $this->add_control(
			'show_details_box',
			array(
				'label' => __( 'Show Detalis Panel', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'show_details_box' ),
					'no'
				),
			)
		);

        $this->add_control(
			'show_product_image',
			array(
				'label' => __( 'Show product image', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'show_product_image' ),
					'yes'
				),
			)
		);

        $this->add_control(
			'show_product_price',
			array(
				'label' => __( 'Show price', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'show_product_price' ),
					'no'
				),
			)
		);

        $this->add_control(
			'show_product_desc',
			array(
				'label' => __( 'Show product description', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'show_product_desc' ),
					'no'
				),
			)
		);

        $this->add_control(
			'show_product_sku',
			array(
				'label' => __( 'Show SKU', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'show_product_sku' ),
					'no'
				),
			)
		);

        $this->add_control(
			'show_product_tax_product_cat',
			array(
				'label' => __( 'Show categories', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'show_product_tax_product_cat' ),
					'no'
				),
			)
		);

        $this->add_control(
			'show_product_tax_product_tag',
			array(
				'label' => __( 'Show tags', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'show_product_tax_product_tag' ),
					'no'
				),
			)
		);
	}

	public function update_options() {

		$settings = get_option( 'dgwt_wcas_settings' );

        $search_no_results_text = Utils::get_kit_option( 'cmsmasters_autocomplete_search_no_results_text', 'No results' );
        $search_see_all_results_text = Utils::get_kit_option( 'cmsmasters_autocomplete_search_see_all_results_text', 'See all products...' );
        $suggestions_limit = Utils::get_kit_option( 'cmsmasters_autocomplete_suggestions_limit', '7' );
        $show_product_image = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_product_image', 'yes' ) ? 'on' : 'off';
        $show_product_price = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_product_price' ) ? 'on' : 'off';
        $show_product_desc = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_product_desc' ) ? 'on' : 'off';
        $show_product_sku = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_product_sku' ) ? 'on' : 'off';
        $show_product_tax_product_cat = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_product_tax_product_cat' ) ? 'on' : 'off';
        $show_product_tax_product_tag = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_product_tax_product_tag' ) ? 'on' : 'off';
        $show_details_box = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_details_box' ) ? 'on' : 'off';

        $options = array(
            'search_no_results_text' => $search_no_results_text,
            'search_see_all_results_text' => $search_see_all_results_text,
            'suggestions_limit' => $suggestions_limit,
            'show_product_image' => $show_product_image,
            'show_product_price' => $show_product_price,
            'show_product_desc' => $show_product_desc,
            'show_product_sku' => $show_product_sku,
            'show_product_tax_product_cat' => $show_product_tax_product_cat,
            'show_product_tax_product_tag' => $show_product_tax_product_tag,
            'show_details_box' => $show_details_box,
			'show_grouped_results' => 'on',
        );

		foreach( $options as $key => $value ) {

			if ( is_string( $key ) && ! empty( $key ) ) {
				
				if ( isset( $settings[ $key ] ) ) {
					DGWT_WCAS()->settings->updateOpt( $key, $value );
				}
			}
		}
	}
}
