<?php
namespace TrendyBabySpace\FiboAjaxSearch\CmsmastersFramework\Kits\Settings\FiboAjaxSearch;

use TrendyBabySpace\Kits\Settings\Base\Settings_Tab_Base;

use Elementor\Controls_Manager;
use TrendyBabySpace\Core\Utils\Utils;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Gutenberg settings.
 */
class Search_Settings extends Settings_Tab_Base {

	public function __construct( $data = array(), $args = null ) {
        parent::__construct( $data, $args );

		$settings = get_option( 'dgwt_wcas_settings' );

		if ( isset( $settings ) || !empty( $settings ) ) {
			add_action( 'admin_init', array( $this, 'update_options' ), 11, 2 );
		}
	}

	/**
	 * Get toggle name.
	 *
	 * Retrieve the toggle name.
	 *
	 * @return string Toggle name.
	 */
	public static function get_toggle_name() {
		return 'search-settings';
	}

	/**
	 * Get title.
	 *
	 * Retrieve the toggle title.
	 */
	public function get_title() {
		return esc_html__( 'Search', 'trendy-baby' );
	}

	/**
	 * Get control ID prefix.
	 *
	 * Retrieve the control ID prefix.
	 *
	 * @return string Control ID prefix.
	 */
	protected static function get_control_id_prefix() {
		$toggle_name = self::get_toggle_name();

		return parent::get_control_id_prefix() . "_{$toggle_name}";
	}

	/**
	* Register toggle controls.
	*
	* Registers the controls of the kit settings tab toggle.
	*/
	protected function register_toggle_controls() {
		$this->add_control(
			'min_chars',
			array(
				'label' => __( 'Minimum characters', 'trendy-baby' ),
				'type' => Controls_Manager::NUMBER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'min_chars' ),
					'3'
				),
				'description' => __( 'Min characters to show autocomplete', 'trendy-baby' ),
			)
		);

        $this->add_control(
			'search_in_product_content',
			array(
				'label' => __( 'Search in description', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'search_in_product_content' ),
					'yes'
				),
			)
		);

        $this->add_control(
			'search_in_product_excerpt',
			array(
				'label' => __( 'Search in short description', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'search_in_product_excerpt' ),
					'yes'
				),
			)
		);

        $this->add_control(
			'search_in_product_sku',
			array(
				'label' => __( 'Search in SKU', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'search_in_product_sku' ),
					'yes'
				),
			)
		);

        $this->add_control(
			'exclude_out_of_stock',
			array(
				'label' => __( 'Exclude "out of stock"', 'trendy-baby' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => $this->get_default_setting(
					$this->get_control_name_parameter( '', 'exclude_out_of_stock' ),
					'no'
				),
			)
		);
	}

	public function update_options() {
		$settings = get_option( 'dgwt_wcas_settings' );

		$min_chars = Utils::get_kit_option( 'cmsmasters_autocomplete_min_chars', '3' );
        $search_in_product_content = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_search_in_product_content', 'yes' ) ? 'on' : 'off';
        $search_in_product_excerpt = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_search_in_product_excerpt', 'yes' ) ? 'on' : 'off';
        $search_in_product_sku = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_show_details_boxsearch_in_product_sku', 'yes' ) ? 'on' : 'off';
        $exclude_out_of_stock = 'yes' === Utils::get_kit_option( 'cmsmasters_autocomplete_exclude_out_of_stock', 'off' ) ? 'on' : 'no';

        $options = array(
            'min_chars' => $min_chars,
            'search_in_product_content' => $search_in_product_content,
            'search_in_product_excerpt' => $search_in_product_excerpt,
            'search_in_product_sku' => $search_in_product_sku,
            'exclude_out_of_stock' => $exclude_out_of_stock,
        );

		foreach( $options as $key => $value ) {

			if ( is_string( $key ) && ! empty( $key ) ) {

				if ( isset( $settings[ $key ] ) ) {
					DGWT_WCAS()->settings->updateOpt( $key, $value );
				}
			}
		}
	}
}
