<?php
namespace TrendyBabySpace\Wpclever\CmsmastersFramework\Kits\Settings\Wpclever;

use TrendyBabySpace\Kits\Settings\Base\Settings_Tab_Base;

use Elementor\Controls_Manager;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Gutenberg settings.
 */
class Compare extends Settings_Tab_Base {

	/**
	 * Get toggle name.
	 *
	 * Retrieve the toggle name.
	 *
	 * @return string Toggle name.
	 */
	public static function get_toggle_name() {
		return 'compare';
	}

	/**
	 * Get title.
	 *
	 * Retrieve the toggle title.
	 */
	public function get_title() {
		return esc_html__( 'Compare', 'trendy-baby' );
	}

	/**
	 * Get control ID prefix.
	 *
	 * Retrieve the control ID prefix.
	 *
	 * @return string Control ID prefix.
	 */
	protected static function get_control_id_prefix() {
		$toggle_name = self::get_toggle_name();

		return parent::get_control_id_prefix() . "_{$toggle_name}";
	}

	/**
	 * Register toggle controls.
	 *
	 * Registers the controls of the kit settings tab toggle.
	 */
	protected function register_toggle_controls() {
		$this->add_control(
			'cm_thead',
			array(
				'label' => esc_html__( 'Header', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
			)
		);

		$this->add_var_group_control( 'cm_thead', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'cm_thead_title_color',
			array(
				'label' => esc_html__( 'Title Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_thead_title_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_thead_title_color_hover',
			array(
				'label' => esc_html__( 'Title Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_thead_title_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_thead_remove_color',
			array(
				'label' => esc_html__( 'Remove Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_thead_remove_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_thead_remove_color_hover',
			array(
				'label' => esc_html__( 'Remove Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_thead_remove_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_thead_bg_color',
			array(
				'label' => esc_html__( 'Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_thead_bg_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'cm_thead_padding',
			array(
				'label' => esc_html__( 'Items Padding', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_thead_padding_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_thead_padding_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_thead_padding_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_thead_padding_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'cm_image',
			array(
				'label' => esc_html__( 'Image', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_responsive_control(
			'cm_image_height',
			array(
				'label' => esc_html__( 'Height', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 1000,
					),
					'vh' => array(
						'min' => 0,
						'max' => 100,
					),
					'vw' => array(
						'min' => 0,
						'max' => 100,
					),
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units' => array(
					'px',
					'vh',
					'vw',
					'%',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_image_height' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'cm_image_fit',
			array(
				'label' => __( 'Image Fit', 'trendy-baby' ),
				'type' => Controls_Manager::SELECT,
				'options' => array(
					'default' => __( 'Default', 'trendy-baby' ),
					'contain' => __( 'Contain', 'trendy-baby' ),
					'cover' => __( 'Cover', 'trendy-baby' ),
					'fill' => __( 'Fill', 'trendy-baby' ),
					'scale-down' => __( 'Scale Down', 'trendy-baby' ),
				),
				'default' => 'default',
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_image_fit' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_var_group_control( 'cm_product_image_bd', self::VAR_BORDER, array(
			'fields_options' => array(
				'width' => array( 'label' => esc_html__( 'Border', 'trendy-baby' ) ),
			),
		) );

		$this->add_responsive_control(
			'cm_product_image_bdr',
			array(
				'label' => esc_html__( 'Border Radius', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_product_image_bdr_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_product_image_bdr_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_product_image_bdr_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_product_image_bdr_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'cm_body',
			array(
				'label' => esc_html__( 'Body', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'cm_body', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'cm_body_label_color',
			array(
				'label' => esc_html__( 'Label Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_body_label_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_body_text_color',
			array(
				'label' => esc_html__( 'Text Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_body_text_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_tbody_even_bg_color',
			array(
				'label' => esc_html__( 'Even Line Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_body_even_bg_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_tbody_odd_bg_color',
			array(
				'label' => esc_html__( 'Odd Line Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_body_odd_bg_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'cm_body_padding',
			array(
				'label' => esc_html__( 'Items Padding', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_body_padding_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_body_padding_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_body_padding_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'cm_body_padding_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'cm_add_button',
			array(
				'label' => esc_html__( 'Button', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_controls_group( 'cm_button', self::CONTROLS_BUTTONS, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
		) );

		$this->add_control(
			'cm_close_control_heading',
			array(
				'label' => esc_html__( 'Close', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_responsive_control(
			'cm_close_size',
			array(
				'label' => esc_html__( 'Size', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 20,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_close_size' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_controls_group( 'cm_close', self::CONTROLS_STATES, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
			'border' => false,
			'bd_radius' => false,
			'box_shadow' => false,
		) );

		$this->add_control(
			'cm_bar_control_heading',
			array(
				'label' => esc_html__( 'Bar', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_control(
			'cm_bar_bg_color',
			array(
				'label' => esc_html__( 'Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_bar_bg_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'cm_bar_button_bg_color',
			array(
				'label' => esc_html__( 'Button Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'cm_bar_button_bg_color' ) . ': {{VALUE}};',
				),
			)
		);
	}
}
