<?php
namespace TrendyBabySpace\Wpclever\CmsmastersFramework\Kits\Settings\Wpclever;

use TrendyBabySpace\Kits\Settings\Base\Settings_Tab_Base;

use Elementor\Controls_Manager;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Gutenberg settings.
 */
class Quick_View extends Settings_Tab_Base {

	/**
	 * Get toggle name.
	 *
	 * Retrieve the toggle name.
	 *
	 * @return string Toggle name.
	 */
	public static function get_toggle_name() {
		return 'quick-view';
	}

	/**
	 * Get title.
	 *
	 * Retrieve the toggle title.
	 */
	public function get_title() {
		return esc_html__( 'Quick View', 'trendy-baby' );
	}

	/**
	 * Get control ID prefix.
	 *
	 * Retrieve the control ID prefix.
	 *
	 * @return string Control ID prefix.
	 */
	protected static function get_control_id_prefix() {
		$toggle_name = self::get_toggle_name();

		return parent::get_control_id_prefix() . "_{$toggle_name}";
	}

	/**
	 * Register toggle controls.
	 *
	 * Registers the controls of the kit settings tab toggle.
	 */
	protected function register_toggle_controls() {
		$this->add_responsive_control(
			'qv_width',
			array(
				'label' => esc_html__( 'Max Wrapper Width', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 1200,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_width' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_height',
			array(
				'label' => esc_html__( 'Image Height', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 800,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_height' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		if ( class_exists( 'WPCleverWpcvs' ) ) {
			$this->add_responsive_control(
				'qv_variation_section_gap',
				array(
					'label' => esc_html__( 'WPC Variation Sections Gap', 'trendy-baby' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'px' => array(
							'min' => 0,
							'max' => 100,
						),
						'%' => array(
							'min' => 0,
							'max' => 100,
						),
						'rem' => array(
							'min' => 0,
							'max' => 10,
						),
					),
					'size_units' => array(
						'px',
						'%',
						'rem',
					),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_section_gap' ) . ': {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_responsive_control(
				'qv_variation_box_margin',
				array(
					'label' => esc_html__( 'WPC Variation Box Margin', 'trendy-baby' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', '%', 'rem' ),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin_top' ) . ': {{TOP}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin_left' ) . ': {{LEFT}}{{UNIT}};',
					),
				)
			);
		}

		$this->add_control(
			'qv_header',
			array(
				'label' => esc_html__( 'Header', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_header', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'qv_header_color',
			array(
				'label' => esc_html__( 'Text Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_header_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_header_close_color',
			array(
				'label' => esc_html__( 'Close Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_header_close_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_header_close_color_hover',
			array(
				'label' => esc_html__( 'Close Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_header_close_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_header_bg_color',
			array(
				'label' => esc_html__( 'Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_header_bg_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_product_title_control',
			array(
				'label' => esc_html__( 'Product Title', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_product_title', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'qv_product_title_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_product_title_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_product_title_margin',
			array(
				'label' => esc_html__( 'Margin', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_product_title_margin_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_product_title_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_product_title_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_product_title_margin_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_rating_control_heading',
			array(
				'label' => esc_html__( 'Rating', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_product_rating', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'qv_rating_star_color',
			array(
				'label' => esc_html__( 'Star Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_rating_star_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_rating_text_color',
			array(
				'label' => esc_html__( 'Text Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_rating_text_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_rating_text_color_hover',
			array(
				'label' => esc_html__( 'Text Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_rating_text_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_rating_margin',
			array(
				'label' => esc_html__( 'Margin', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_rating_margin_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_rating_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_rating_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_rating_margin_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_price_control_heading',
			array(
				'label' => esc_html__( 'Price', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_product_price', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'qv_sale_color',
			array(
				'label' => esc_html__( 'Sale Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_sale_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_price_color',
			array(
				'label' => esc_html__( 'Price Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_price_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_price_margin',
			array(
				'label' => esc_html__( 'Margin', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_price_margin_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_price_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_price_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_price_margin_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_description_control_heading',
			array(
				'label' => esc_html__( 'Description', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_product_description', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'qv_description_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_description_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_description_margin',
			array(
				'label' => esc_html__( 'Margin', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_description_margin_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_description_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_description_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_description_margin_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_stock_control_heading',
			array(
				'label' => esc_html__( 'Stock', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_stock', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'qv_in_stock_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_in_stock_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_out_stock_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_out_stock_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_stock_margin',
			array(
				'label' => esc_html__( 'Margin', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_stock_margin_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_stock_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_stock_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_stock_margin_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		if ( class_exists( 'WPCleverWpcvs' ) ) {
			$this->add_control(
				'qv_variation_labels_heading_control',
				array(
					'label' => esc_html__( 'WPC Variation Labels', 'trendy-baby' ),
					'type' => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);
	
			$this->add_var_group_control( 'qv_variation_label', self::VAR_TYPOGRAPHY );
	
			$this->add_control(
				'qv_variation_label_color',
				array(
					'label' => esc_html__( 'Color', 'trendy-baby' ),
					'type' => Controls_Manager::COLOR,
					'dynamic' => array(),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_label_color' ) . ': {{VALUE}};',
					),
				)
			);
	
			$this->add_responsive_control(
				'qv_varition_label_gap',
				array(
					'label' => esc_html__( 'Gap', 'trendy-baby' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'%' => array(
							'min' => 0,
							'max' => 100,
						),
						'px' => array(
							'min' => 0,
							'max' => 50,
						),
						'rem' => array(
							'min' => 0,
							'max' => 10,
						),
					),
					'size_units' => array(
						'%',
						'px',
						'rem',
					),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_label_gap' ) . ': {{SIZE}}{{UNIT}};',
					),
				)
			);
	
			$this->add_control(
				'qv_variation_type_button',
				array(
					'label' => esc_html__( 'WPC Variation Type Button', 'trendy-baby' ),
					'type' => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_var_group_control( 'qv_variation_type_button', self::VAR_TYPOGRAPHY );

			$this->add_controls_group( 'qv_variation_type_button', self::CONTROLS_STATES, array(
				'states' => array(
					'normal' => esc_html__( 'Normal', 'trendy-baby' ),
					'hover' => esc_html__( 'Hover', 'trendy-baby' ),
					'selected' => esc_html__( 'Selected', 'trendy-baby' ),
				),
			) );

			$this->add_responsive_control(
				'qv_varition_type_button_padding',
				array(
					'label' => esc_html__( 'Padding', 'trendy-baby' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', '%', 'rem' ),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_type_button_padding_top' ) . ': {{TOP}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_type_button_padding_right' ) . ': {{RIGHT}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_type_button_padding_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_type_button_padding_left' ) . ': {{LEFT}}{{UNIT}};',
					),
				)
			);

			$this->add_responsive_control(
				'qv_varition_type_button_gap',
				array(
					'label' => esc_html__( 'Gap', 'trendy-baby' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'%' => array(
							'min' => 0,
							'max' => 100,
						),
						'px' => array(
							'min' => 0,
							'max' => 50,
						),
						'rem' => array(
							'min' => 0,
							'max' => 10,
						),
					),
					'size_units' => array(
						'%',
						'px',
						'rem',
					),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_type_button_gap' ) . ': {{SIZE}}{{UNIT}};',
					),
				)
			);
	
			$this->add_control(
				'qv_variation_type_color_heading',
				array(
					'label' => esc_html__( 'WPC Variation Type Color', 'trendy-baby' ),
					'type' => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);
	
			$this->add_controls_group( 'qv_variation_type_color', self::CONTROLS_STATES, array(
				'states' => array(
					'normal' => esc_html__( 'Normal', 'trendy-baby' ),
					'hover' => esc_html__( 'Hover', 'trendy-baby' ),
					'selected' => esc_html__( 'Selected', 'trendy-baby' ),
				),
				'background' => false,
				'color' => false,
			) );
	
			$this->add_responsive_control(
				'qv_varition_type_color_gap',
				array(
					'label' => esc_html__( 'Gap', 'trendy-baby' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'%' => array(
							'min' => 0,
							'max' => 100,
						),
						'px' => array(
							'min' => 0,
							'max' => 50,
						),
						'rem' => array(
							'min' => 0,
							'max' => 10,
						),
					),
					'size_units' => array(
						'%',
						'px',
						'rem',
					),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_type_color_gap' ) . ': {{SIZE}}{{UNIT}};',
					),
				)
			);
	
			$this->add_control(
				'qv_variation_type_image_heading',
				array(
					'label' => esc_html__( 'WPC Variation Type Image', 'trendy-baby' ),
					'type' => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);
	
			$this->add_controls_group( 'qv_variation_type_image', self::CONTROLS_STATES, array(
				'states' => array(
					'normal' => esc_html__( 'Normal', 'trendy-baby' ),
					'hover' => esc_html__( 'Hover', 'trendy-baby' ),
					'selected' => esc_html__( 'Selected', 'trendy-baby' ),
				),
				'background' => false,
				'color' => false,
			) );
	
			$this->add_responsive_control(
				'qv_varition_type_image_gap',
				array(
					'label' => esc_html__( 'Gap', 'trendy-baby' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'%' => array(
							'min' => 0,
							'max' => 100,
						),
						'px' => array(
							'min' => 0,
							'max' => 50,
						),
						'rem' => array(
							'min' => 0,
							'max' => 10,
						),
					),
					'size_units' => array(
						'%',
						'px',
						'rem',
					),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_type_image_gap' ) . ': {{SIZE}}{{UNIT}};',
					),
				)
			);
	
			$this->add_control(
				'qv_variation_type_radio_heading',
				array(
					'label' => esc_html__( 'WPC Variation Type Radio', 'trendy-baby' ),
					'type' => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_var_group_control( 'qv_variation_type_radio', self::VAR_TYPOGRAPHY );
	
			$this->add_controls_group( 'qv_variation_type_radio', self::CONTROLS_STATES, array(
				'states' => array(
					'normal' => esc_html__( 'Normal', 'trendy-baby' ),
					'hover' => esc_html__( 'Hover', 'trendy-baby' ),
					'selected' => esc_html__( 'Selected', 'trendy-baby' ),
				),
				'color' => true,
				'background' => false,
				'border' => false,
				'bd_radius' => false,
				'box_shadow' => false,
			) );
	
			$this->add_responsive_control(
				'qv_varition_type_radio_gap',
				array(
					'label' => esc_html__( 'Gap', 'trendy-baby' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'%' => array(
							'min' => 0,
							'max' => 100,
						),
						'px' => array(
							'min' => 0,
							'max' => 50,
						),
						'rem' => array(
							'min' => 0,
							'max' => 10,
						),
					),
					'size_units' => array(
						'%',
						'px',
						'rem',
					),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_type_radio_gap' ) . ': {{SIZE}}{{UNIT}};',
					),
				)
			);
		}

		if ( ! class_exists( 'WPCleverWpcvs' ) ) {
			$this->add_control(
				'qv_variation_fields_heading_control',
				array(
					'label' => esc_html__( 'Variation Fields', 'trendy-baby' ),
					'type' => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);
	
			$this->add_var_group_control( 'qv_variation_fields', self::VAR_TYPOGRAPHY );
	
			$this->add_controls_group( 'qv_variation_fields', self::CONTROLS_STATES, array(
				'states' => array(
					'normal' => esc_html__( 'Normal', 'trendy-baby' ),
					'focus' => esc_html__( 'Focus', 'trendy-baby' ),
				),
			) );
	
			$this->add_responsive_control(
				'qv_variation_padding',
				array(
					'label' => esc_html__( 'Padding', 'trendy-baby' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', '%', 'rem' ),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_fields_padding-top' ) . ': {{TOP}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_fields_padding-right' ) . ': {{RIGHT}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_fields_padding-bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_fields_padding-left' ) . ': {{LEFT}}{{UNIT}};',
					),
				)
			);
	
			$this->add_responsive_control(
				'qv_fields_gap',
				array(
					'label' => esc_html__( 'Fields Gap', 'trendy-baby' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'%' => array(
							'min' => 0,
							'max' => 100,
						),
						'px' => array(
							'min' => 0,
							'max' => 100,
						),
						'rem' => array(
							'min' => 0,
							'max' => 10,
						),
					),
					'size_units' => array(
						'%',
						'px',
						'rem',
					),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_fields_gap' ) . ': {{SIZE}}{{UNIT}};',
					),
				)
			);
	
			$this->add_responsive_control(
				'qv_variation_margin',
				array(
					'label' => esc_html__( 'Box Margin', 'trendy-baby' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', '%', 'rem' ),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin-top' ) . ': {{TOP}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin-right' ) . ': {{RIGHT}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin-bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
							'--' . $this->get_control_prefix_parameter( '', 'qv_variation_box_margin-left' ) . ': {{LEFT}}{{UNIT}};',
					),
				)
			);
	
			$this->add_control(
				'qv_variation_labels_heading_control',
				array(
					'label' => esc_html__( 'Variation Labels', 'trendy-baby' ),
					'type' => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);
	
			$this->add_var_group_control( 'qv_variation_label', self::VAR_TYPOGRAPHY );
	
			$this->add_control(
				'qv_variation_label_color',
				array(
					'label' => esc_html__( 'Color', 'trendy-baby' ),
					'type' => Controls_Manager::COLOR,
					'dynamic' => array(),
					'selectors' => array(
						':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_label_color' ) . ': {{VALUE}};',
					),
				)
			);
		}

		$this->add_control(
			'qv_variation_button_control_heading',
			array(
				'label' => esc_html__( 'Variation Clear Button', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_responsive_control(
			'qv_variation_button_align',
			array(
				'label' => __( 'Alignment', 'trendy-baby' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => array(
					'left' => array(
						'title' => __( 'Left', 'trendy-baby' ),
						'icon' => 'eicon-text-align-left',
					),
					'center' => array(
						'title' => __( 'Center', 'trendy-baby' ),
						'icon' => 'eicon-text-align-center',
					),
					'right' => array(
						'title' => __( 'Right', 'trendy-baby' ),
						'icon' => 'eicon-text-align-right',
					),
					'stretch' => array(
						'title' => __( 'Justified', 'trendy-baby' ),
						'icon' => 'eicon-text-align-justify',
					),
				),
				'selectors_dictionary' => array(
					'left' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_button_align' ) . ': start;',
					'center' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_button_align' ) . ': center;',
					'right' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_button_align' ) . ': end;',
					'stretch' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_button_align' ) . ': 100%;',
				),
				'toggle' => false,
				'default' => 'left',
				'selectors' => array(
					':root' => '{{VALUE}};',
				),
			)
		);

		$this->add_controls_group( 'qv_variation_button', self::CONTROLS_BUTTONS, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
		) );

		$this->add_responsive_control(
			'qv_variation_button_gap',
			array(
				'label' => esc_html__( 'Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
					'px' => array(
						'min' => 0,
						'max' => 100,
					),
					'rem' => array(
						'min' => 0,
						'max' => 10,
					),
				),
				'size_units' => array(
					'%',
					'px',
					'rem',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_variation_button_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_quantity_heading_control',
			array(
				'label' => esc_html__( 'Quantity', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_quantity_fields', self::VAR_TYPOGRAPHY );

		$this->add_controls_group( 'qv_quantity_fields', self::CONTROLS_STATES, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'focus' => esc_html__( 'Focus', 'trendy-baby' ),
			),
		) );

		$this->add_responsive_control(
			'qv_quantity_padding',
			array(
				'label' => esc_html__( 'Padding', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_quantity_fields_padding-top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_quantity_fields_padding-right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_quantity_fields_padding-bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_quantity_fields_padding-left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_button_control_heading',
			array(
				'label' => esc_html__( 'Add to Cart Button', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_controls_group( 'qv_button', self::CONTROLS_BUTTONS, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
		) );

		$this->add_responsive_control(
			'qv_button_margin',
			array(
				'label' => esc_html__( 'Margin', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_button_margin_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_button_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_button_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_button_margin_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_meta_control_heading',
			array(
				'label' => esc_html__( 'Meta', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_product_meta', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'qv_meta_label_color',
			array(
				'label' => esc_html__( 'Text Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_meta_label_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_meta_link_color',
			array(
				'label' => esc_html__( 'Link Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_meta_link_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'qv_meta_link_color_hover',
			array(
				'label' => esc_html__( 'Link Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_meta_link_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_meta_gap',
			array(
				'label' => esc_html__( 'Meta Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
					'px' => array(
						'min' => 0,
						'max' => 100,
					),
					'rem' => array(
						'min' => 0,
						'max' => 10,
					),
				),
				'size_units' => array(
					'%',
					'px',
					'rem',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_meta_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_meta_margin',
			array(
				'label' => esc_html__( 'Margin', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_meta_margin_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_meta_margin_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_meta_margin_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'qv_meta_margin_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'qv_arrow_control_heading',
			array(
				'label' => esc_html__( 'Arrow', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_responsive_control(
			'qv_arrow_size',
			array(
				'label' => esc_html__( 'Size', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 40,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_arrow_size' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_arrow_box_size',
			array(
				'label' => esc_html__( 'Box Size', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_arrow_box_size' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'qv_arrow_box_gap',
			array(
				'label' => esc_html__( 'Box Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 50,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_arrow_box_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_controls_group( 'qv_arrow', self::CONTROLS_STATES, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
			'border' => false,
		) );

		$this->add_control(
			'qv_close_control_heading',
			array(
				'label' => esc_html__( 'Close', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_responsive_control(
			'qv_close_size',
			array(
				'label' => esc_html__( 'Size', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 20,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'qv_close_size' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_controls_group( 'qv_close', self::CONTROLS_STATES, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
			'border' => false,
			'bd_radius' => false,
			'box_shadow' => false,
		) );

		$this->add_control(
			'qv_button_detalis_control_heading',
			array(
				'label' => esc_html__( 'Button Detalis', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'qv_product_detalis', self::VAR_TYPOGRAPHY );

		$this->add_controls_group( 'qv_detalis', self::CONTROLS_STATES, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
			'border' => false,
			'bd_radius' => false,
			'box_shadow' => false,
		) );
	}
}
