<?php
namespace TrendyBabySpace\Wpclever\CmsmastersFramework\Kits\Settings\Wpclever;

use TrendyBabySpace\Kits\Settings\Base\Settings_Tab_Base;

use Elementor\Controls_Manager;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Gutenberg settings.
 */
class Wishlist_Compare_Message extends Settings_Tab_Base {

	/**
	 * Get toggle name.
	 *
	 * Retrieve the toggle name.
	 *
	 * @return string Toggle name.
	 */
	public static function get_toggle_name() {
		return 'wishlist-compare-message';
	}

	/**
	 * Get title.
	 *
	 * Retrieve the toggle title.
	 */
	public function get_title() {
		return esc_html__( 'Wishlist & Compare Added Message', 'trendy-baby' );
	}

	/**
	 * Get control ID prefix.
	 *
	 * Retrieve the control ID prefix.
	 *
	 * @return string Control ID prefix.
	 */
	protected static function get_control_id_prefix() {
		$toggle_name = self::get_toggle_name();

		return parent::get_control_id_prefix() . "_{$toggle_name}";
	}

	/**
	 * Register toggle controls.
	 *
	 * Registers the controls of the kit settings tab toggle.
	 */
	protected function register_toggle_controls() {
		$this->add_control(
			'wc_image_heading',
			array(
				'label' => esc_html__( 'Image', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
			)
		);

		$this->add_controls_group( 'wc_image', self::CONTROLS_CONTAINER_BOX, array(
			'popover' => false,
			'excludes' => array( 'alignment', 'margin', 'bg_color', 'padding' ),
		) );

		$this->add_control(
			'wc_text_heading',
			array(
				'label' => esc_html__( 'Text', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wc_text', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'wc_text_color',
			array(
				'label' => esc_html__( 'Text Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wc_text_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wc_box_heading',
			array(
				'label' => esc_html__( 'Box', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_controls_group( 'wc_box', self::CONTROLS_CONTAINER_BOX, array(
			'popover' => false,
			'excludes' => array( 'alignment', 'margin' ),
		) );
	}
}
