<?php
namespace TrendyBabySpace\Wpclever\CmsmastersFramework\Kits\Settings\Wpclever;

use TrendyBabySpace\Kits\Settings\Base\Settings_Tab_Base;

use Elementor\Controls_Manager;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Gutenberg settings.
 */
class Wishlist extends Settings_Tab_Base {

	/**
	 * Get toggle name.
	 *
	 * Retrieve the toggle name.
	 *
	 * @return string Toggle name.
	 */
	public static function get_toggle_name() {
		return 'wishlist';
	}

	/**
	 * Get title.
	 *
	 * Retrieve the toggle title.
	 */
	public function get_title() {
		return esc_html__( 'Wishlist', 'trendy-baby' );
	}

	/**
	 * Get control ID prefix.
	 *
	 * Retrieve the control ID prefix.
	 *
	 * @return string Control ID prefix.
	 */
	protected static function get_control_id_prefix() {
		$toggle_name = self::get_toggle_name();

		return parent::get_control_id_prefix() . "_{$toggle_name}";
	}

	/**
	 * Register toggle controls.
	 *
	 * Registers the controls of the kit settings tab toggle.
	 */
	protected function register_toggle_controls() {
		$this->add_responsive_control(
			'wl_product_box_size',
			array(
				'label' => esc_html__( 'Box Width', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 1000,
					),
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units' => array(
					'px',
					'%',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_box_size' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'wl_product_box_height',
			array(
				'label' => esc_html__( 'Box Height', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 1000,
					),
					'vh' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units' => array(
					'px',
					'vh',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_box_height' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'wl_product_item_gap',
			array(
				'label' => esc_html__( 'Product Items Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 30,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_item_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'wl_header',
			array(
				'label' => esc_html__( 'Header', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wl_header', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'wl_header_color',
			array(
				'label' => esc_html__( 'Text Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_header_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_header_close_color',
			array(
				'label' => esc_html__( 'Close Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_header_close_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_header_close_color_hover',
			array(
				'label' => esc_html__( 'Close Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_header_close_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_header_bg_color',
			array(
				'label' => esc_html__( 'Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_header_bg_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_product_remove',
			array(
				'label' => esc_html__( 'Product Remove', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_responsive_control(
			'wl_product_remove_size',
			array(
				'label' => esc_html__( 'Size', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 30,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_remove_size' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'wl_product_remove_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_remove_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_product_remove_color_hover',
			array(
				'label' => esc_html__( 'Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_remove_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_product_image',
			array(
				'label' => esc_html__( 'Product Image', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wl_product_image_bd', self::VAR_BORDER, array(
			'fields_options' => array(
				'width' => array( 'label' => esc_html__( 'Border', 'trendy-baby' ) ),
			),
		) );

		$this->add_responsive_control(
			'wl_product_image_bdr',
			array(
				'label' => esc_html__( 'Border Radius', 'trendy-baby' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'rem' ),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_image_bdr_top' ) . ': {{TOP}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'wl_product_image_bdr_right' ) . ': {{RIGHT}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'wl_product_image_bdr_bottom' ) . ': {{BOTTOM}}{{UNIT}};' .
						'--' . $this->get_control_prefix_parameter( '', 'wl_product_image_bdr_left' ) . ': {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'wl_product_title',
			array(
				'label' => esc_html__( 'Product Title', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wl_product_title', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'wl_product_title_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_title_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_product_title_color_hover',
			array(
				'label' => esc_html__( 'Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_title_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'wl_product_title_gap',
			array(
				'label' => esc_html__( 'Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 30,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_title_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'wl_product_price',
			array(
				'label' => esc_html__( 'Product Price', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wl_product_price', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'wl_product_sale_color',
			array(
				'label' => esc_html__( 'Sale Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_sale_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_product_price_color',
			array(
				'label' => esc_html__( 'Price Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_price_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'wl_product_price_gap',
			array(
				'label' => esc_html__( 'Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 30,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_price_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'wl_product_date',
			array(
				'label' => esc_html__( 'Date', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wl_product_date', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'wl_product_date_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_date_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_product_stock',
			array(
				'label' => esc_html__( 'Stock', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wl_product_stock', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'wl_product_out_stock_color',
			array(
				'label' => esc_html__( 'Out Stock Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_out_stock_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_product_in_stock_color',
			array(
				'label' => esc_html__( 'In Stock Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_in_stock_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'wl_product_stock_gap',
			array(
				'label' => esc_html__( 'Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 30,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_stock_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'wl_product_button',
			array(
				'label' => esc_html__( 'Button', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_controls_group( 'wl_product_button', self::CONTROLS_BUTTONS, array(
			'states' => array(
				'normal' => esc_html__( 'Normal', 'trendy-baby' ),
				'hover' => esc_html__( 'Hover', 'trendy-baby' ),
			),
		) );

		$this->add_control(
			'wl_product_separator',
			array(
				'label' => esc_html__( 'Separator', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_control(
			'wl_product_separator_color',
			array(
				'label' => esc_html__( 'Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_separator_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'wl_product_separator_size',
			array(
				'label' => esc_html__( 'Size', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 5,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_separator_size' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);


		$this->add_responsive_control(
			'wl_product_separator_gap',
			array(
				'label' => esc_html__( 'Gap', 'trendy-baby' ),
				'type' => Controls_Manager::SLIDER,
				'range' => array(
					'px' => array(
						'min' => 0,
						'max' => 60,
					),
				),
				'size_units' => array(
					'px',
				),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_product_separator_gap' ) . ': {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'wl_footer',
			array(
				'label' => esc_html__( 'Footer', 'trendy-baby' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_var_group_control( 'wl_footer', self::VAR_TYPOGRAPHY );

		$this->add_control(
			'wl_footer_link_color',
			array(
				'label' => esc_html__( 'Link Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_footer_link_color' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_footer_link_color_hover',
			array(
				'label' => esc_html__( 'Link Hover Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_footer_link_color_hover' ) . ': {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'wl_footer_bg_color',
			array(
				'label' => esc_html__( 'Background Color', 'trendy-baby' ),
				'type' => Controls_Manager::COLOR,
				'dynamic' => array(),
				'selectors' => array(
					':root' => '--' . $this->get_control_prefix_parameter( '', 'wl_footer_bg_color' ) . ': {{VALUE}};',
				),
			)
		);
	}
}
